"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFilesGallery = useFilesGallery;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const components_1 = require("@gravity-ui/components");
const constants_1 = require("./constants.js");
function useFilesGallery(customFiles) {
    const { openGallery } = (0, components_1.useGallery)();
    return {
        openFilesGallery: React.useCallback((event) => {
            if (!(event.target instanceof HTMLElement)) {
                return false;
            }
            let fileLink = '';
            if (event.target.tagName === 'IMG' && !event.target.closest('a')) {
                fileLink = event.target.getAttribute('src') ?? '';
            }
            else if (event.target.tagName === 'A') {
                fileLink = event.target.getAttribute('href') ?? '';
            }
            if (!fileLink) {
                return false;
            }
            const filesFromContent = [
                ...(event.currentTarget?.querySelectorAll('img,a') ?? []),
            ].reduce((result, element) => {
                const isImage = element.tagName === 'IMG';
                const link = isImage
                    ? element.getAttribute('src')
                    : element.getAttribute('href');
                if (link && !customFiles?.some((item) => item.url === link)) {
                    const extension = link.match(constants_1.extensionRegex)?.[0] || '';
                    if (isImage || constants_1.supportedExtensions.includes(extension)) {
                        const name = (isImage
                            ? element.getAttribute('alt')
                            : element.getAttribute('title')) || '';
                        result.push({
                            ...(constants_1.supportedVideoExtensions.includes(extension)
                                ? (0, components_1.getGalleryItemVideo)({ src: link, name: name })
                                : (0, components_1.getGalleryItemImage)({ src: link, name: name })),
                            url: link,
                        });
                    }
                }
                return result;
            }, []);
            const files = [...(customFiles ?? []), ...filesFromContent];
            const initialItemIndex = files.findIndex((item) => item.url === fileLink);
            if (initialItemIndex !== -1) {
                event.preventDefault();
                openGallery(files, initialItemIndex);
                return true;
            }
            return false;
        }, [customFiles, openGallery]),
    };
}
//# sourceMappingURL=useFilesGallery.js.map
